@@ -1,9 +1,12 @@
 import units_QBD
 from math import sqrt
 
-def eigenvalues_1(space__grid, energy__grid, mass__grid, level__resolution=0.001):
+def eigenvalues_1(space__grid, energy__grid, mass__grid,min__energy__level=0, max__energy__level=12e-19, level__resolution=1e-21):
     energy__grid = [energy / units_QBD.SI_['eV'][0] for energy in energy__grid]
     mass__grid = [mass / units_QBD.SI_['m_e'][0] for mass in mass__grid]
+    level__resolution = level__resolution / units_QBD.SI_['eV'][0]
+    min__energy__level = min__energy__level / units_QBD.SI_['eV'][0]
+    max__energy__level = max__energy__level / units_QBD.SI_['eV'][0]
 
     interval = space__grid[1] - space__grid[0]
     as2 = 2.0 * units_QBD.M_E[0] * units_QBD.E[0] * interval * interval / units_QBD.H__BAR[0] / units_QBD.H__BAR[0]
@@ -25,8 +28,8 @@ def eigenvalues_1(space__grid, energy__grid, mass__grid, level__resolution=0.001
     eigenvalues = []
     level = 2
     while(True):
-        E_min = min(energy__grid)
-        E_max = max(energy__grid)
+        E_min = min__energy__level
+        E_max = max__energy__level
         E_ave = ...
 
         while E_max - E_min > level__resolution:
@@ -73,7 +76,6 @@ def eigenfunctions_1(space__grid, energy__grid, mass__grid, energy):
     AZW_U.append(0)
     AZW_U.append(0)
 
-    print(energy)
     ThetaM = [0] * grid__points__count
     ThetaM[1] = 1. / (AZW_D[1] - energy * as2)
     for i in range(2,grid__points__count):
@@ -107,13 +109,22 @@ def eigenfunctions_1(space__grid, energy__grid, mass__grid, energy):
         i = k - i
         wave__vector[i] = -AZW_U[i] * ThetaM[i] * wave__vector[i + 1]
 
+    # Norma = 0.
+
+    # for i in range(1, grid__points__count): 
+    #     Norma += wave__vector[i] * wave__vector[i]
+    # Norma *= interval
+
+    # for i in range(1, grid__points__count):
+    #     wave__vector[i] /= sqrt(Norma)
+
+    return wave__vector
+
+def normalization(wave__vector, space__grid):
     Norma = 0.
 
-    for i in range(1, grid__points__count): 
-        Norma += wave__vector[i] * wave__vector[i]
-    Norma *= interval
+    for wv in wave__vector: 
+        Norma += wv * wv
+    Norma *= space__grid[1] - space__grid[0]
 
-    for i in range(1, grid__points__count):
-        wave__vector[i] /= sqrt(Norma)
-
-    return wave__vector
\ No newline at end of file
+    return [wv / sqrt(Norma) for wv in wave__vector]
